function out = p3din_FAULT_func_v1_MSH_200m(E,nu,Stress,Pf,filename_in,xyz1,xyz2,xyz3,xyz4,xyz5,xyz6,xyz7,xyz8,tn1,tn2,tn3,tn4,tn5,tn6,tn7,tn8,Pm200,CS_AOInorth,CS_AOIsouth,OBSgridnorth200,OBSgridsouth200)

% Matlab script to create input for systematic analyses of fault meshes.
%
% PURPOSE: generate .in file for "newpoly3d" executable, 1999 C++ version
% v1
%
% 
% Author: J. Ole Kaven
% Date: 8/29/2003
% 
% Version: 1
% Modified By: Michael Swyer
% Date Modified: 8/20/2015
% 
% Input: < >
% Space: Half
% Comments:

scrsz = get(0,'Screensize');
out.vers = 1;
out.date = datestr(now); 
out.space = 'half'; % 'half' --> half space; 'full' = whole space

[fid,message] = fopen(filename_in,'w'); % replace this with variable to treat as function; can give the directory listing for thepoly3D folder

%% Setup stuff:
% Vertices (used to define mesh of "fault")
%   Note: must explicitly do for each fault object

% entriesX = mx4 matrix where m = # of elements.  X is fault number.  row 1 is element number, and rows 2-4 are x,y,z coordinates of element nodes
%   NOTE: must add the last vertex number of the previous fault to the all
%         the vertex numbers of the next fault to eliminate redundancy.

% fault01
entries1(1,:) = 1:(length(xyz1));
entries1(2:4,:) = xyz1';

% fault02
entries2(1,:) = (1+max(entries1(1,:))):(length(xyz2)+max(entries1(1,:)));% first number of this fault is after last number of first fault!!
entries2(2:4,:) = xyz2';

% fault03
entries3(1,:) = (1+max(entries2(1,:))):(length(xyz3)+max(entries2(1,:)));% first number of this fault is after last number of first fault!!
entries3(2:4,:) = xyz3';

% fault04
entries4(1,:) = (1+max(entries3(1,:))):(length(xyz4)+max(entries3(1,:)));% first number of this fault is after last number of first fault!!
entries4(2:4,:) = xyz4';

% fault05
entries5(1,:) = (1+max(entries4(1,:))):(length(xyz5)+max(entries4(1,:)));% first number of this fault is after last number of first fault!!
entries5(2:4,:) = xyz5';

% fault06
entries6(1,:) = (1+max(entries5(1,:))):(length(xyz6)+max(entries5(1,:)));% first number of this fault is after last number of first fault!!
entries6(2:4,:) = xyz6';

% fault07
entries7(1,:) = (1+max(entries6(1,:))):(length(xyz7)+max(entries6(1,:)));% first number of this fault is after last number of first fault!!
entries7(2:4,:) = xyz7';

% magma chamber
entries8(1,:) = (1+max(entries7(1,:))):(length(xyz8)+max(entries7(1,:)));% first number of this fault is after last number of first fault!!
entries8(2:4,:) = xyz8';

% **************************************************
% *Surfaces & Elements & Boundary Conditions (aux3)*                        % ******* TO SPECIFY ELEMENT B.C. MODIFY aux3 
% **************************************************

%   NOTE: traction boundary conditions are specified relative to the local
%         element normal. The normals are based on the polarity (order in which the
%         vertices are specified in dat.tri)

%   NOTE: must add the last vertex number of the previous fault to the all
%         the vertex numbers of the next fault to eliminate redundancy*

% fault01
aux3 = zeros(size(tn1)); % must double check dir of normals!     % mx3 array m = number of elements --> these first three columns are the traction or burgers vector BC on each element
fault01 = [aux3 tn1]';clear aux3

% fault02
aux3 = zeros(size(tn2)); % must double check dir of normals!     % mx3 array m = number of elements --> these first three columns are the traction or burgers vector BC on each element
fault02 = [aux3 (tn2+max(entries1(1,:)))]';clear aux3% *Note the addition of last element number*

% fault03
aux3 = zeros(size(tn3)); % must double check dir of normals!     % mx3 array m = number of elements --> these first three columns are the traction or burgers vector BC on each element
% aux3(:,2) = -21.65;% along strike displacement boundary
% aux3(:,1) = 12.5;% down dip displacement boundary
fault03 = [aux3 (tn3+max(entries2(1,:)))]';clear aux3% *Note the addition of last element number*

% fault04
aux3 = zeros(size(tn4)); % must double check dir of normals!     % mx3 array m = number of elements --> these first three columns are the traction or burgers vector BC on each element
fault04 = [aux3 (tn4+max(entries3(1,:)))]';clear aux3% *Note the addition of last element number*

% fault05
aux3 = zeros(size(tn5)); % must double check dir of normals!     % mx3 array m = number of elements --> these first three columns are the traction or burgers vector BC on each element
fault05 = [aux3 (tn5+max(entries4(1,:)))]';clear aux3% *Note the addition of last element number*

% fault06
aux3 = zeros(size(tn6)); % must double check dir of normals!     % mx3 array m = number of elements --> these first three columns are the traction or burgers vector BC on each element
% aux3(:,2) = -4.3;% displacement boundary
fault06 = [aux3 (tn6+max(entries5(1,:)))]';clear aux3% *Note the addition of last element number*

% fault07
aux3 = zeros(size(tn7)); % must double check dir of normals!     % mx3 array m = number of elements --> these first three columns are the traction or burgers vector BC on each element
fault07 = [aux3 (tn7+max(entries6(1,:)))]';clear aux3% *Note the addition of last element number*

% magma chamber
aux3 = zeros(size(tn8)); % must double check dir of normals!     % mx3 array m = number of elements --> these first three columns are the traction or burgers vector BC on each element
aux3(:,3) = Pm200;% 200m obs depth
fault08 = [aux3 (tn8+max(entries7(1,:)))]';clear aux3% *Note the addition of last element number*

% ***************
% *Stress Tensor*
% ***************
S11 = Stress(1,1);
S22 = Stress(2,2);
S33 = Stress(3,3);
S12 = Stress(1,2);
S13 = Stress(1,3);
S23 = Stress(2,3);

%% Generate .in file

fprintf(fid,'*******************************************************************************\n');
fprintf(fid,'*                            Section 1: CONSTANTS                             *\n');
fprintf(fid,'*******************************************************************************\n');
fprintf(fid,'* Titles\n');
fprintf(fid,'*--------\n');
fprintf(fid,'\n');
fprintf(fid,'title1 = "Two fault surfaces to model fault overlap."\n');
fprintf(fid,'\n');
fprintf(fid,'* Elastic Constants\n');
fprintf(fid,'* Specify any two. Leave the rest blank.\n');
fprintf(fid,'*----------------------------------------\n');
fprintf(fid,'shear_mod         = \n');
fprintf(fid,'psn_ratio         = %d\n',nu);                                 % <-- Input poisson's ratio
fprintf(fid,'youngs_mod        = %d\n',E);                                  % <-- Input Young's modulus
fprintf(fid,'bulk_mod          =\n');
fprintf(fid,'lame_lambda       =\n');
fprintf(fid,'\n');
fprintf(fid,'* Remote Stresses/Strains\n');
fprintf(fid,'rem_bc_type       = stress            *(stress/strain)\n');
fprintf(fid,'s11r              = %d\n',S11 + Pf);                           % <-- remote stress tensor, use a tensor transform in a MASTER function to define
fprintf(fid,'s22r              = %d\n',S22 + Pf);
fprintf(fid,'s33r              = %d\n',S33 + Pf);
fprintf(fid,'s12r              = %d\n',S12);
fprintf(fid,'s13r              = %d\n',S13);
fprintf(fid,'s23r              = %d\n',S23);
fprintf(fid,'\n');
fprintf(fid,'* Options\n'); 
fprintf(fid,'*---------\n');
fprintf(fid,'half_space        = yes                *(yes/no)\n');          % <-- for whole space replace "= yes" with "= no"
fprintf(fid,'check_cond_num    = yes               *(yes/no)\n');           % avoid numbers greater than 10^-8 or 10^-6
fprintf(fid,'print_elt_geom    = yes               *(yes/no)\n'); 
fprintf(fid,'elt_geom_csys     = global\n'); 
fprintf(fid,'null_value        = -999.0\n');
fprintf(fid,'\n');
fprintf(fid,'end *(CONSTANTS)\n');
fprintf(fid,'*******************************************************************************\n');
fprintf(fid,'*                        Section 2: USER COORDINATE SYSTEMS                   *\n');
fprintf(fid,'*******************************************************************************\n');
fprintf(fid,'* (1)        (2)     (3)    (4)    (5)     (6)     (7)     (8)       (9)\n');
fprintf(fid,'*name      parent    x1o    x2o    x3o    rot1    rot2    rot3    rot order\n');
fprintf(fid,'*--------- --------- ------ ------ ------ ------- ------- ------- ---------\n');
xcent = 0;ycent = 0;zcent = 0;rot1 = 0;	rot2 = 0;	rot3 = 0;
defaul = [xcent, ycent, zcent, rot1, rot2, rot3, 321]; 
fprintf(fid,'CrackCS    global %7.6f %7.6f %7.6f %7.1f %7.1f %7.1f %5.0f\n',defaul);
fprintf(fid,'CS_AOInorth    global %7.6f %7.6f %7.6f %7.1f %7.1f %7.1f %5.0f\n',CS_AOInorth);
fprintf(fid,'CS_AOIsouth    global %7.6f %7.6f %7.6f %7.1f %7.1f %7.1f %5.0f\n',CS_AOIsouth);
fprintf(fid,'\n');
fprintf(fid,'end *(USER COORDINATE SYSTEMS)\n');
fprintf(fid,'*******************************************************************************\n');
fprintf(fid,'*                         Section 3: OBSERVATION GRIDS                        *\n');
fprintf(fid,'*******************************************************************************\n');
fprintf(fid,'* (1)    (2) (3)      (4)        (5)        (6)     (7)    (8)    (9)    (10)   (11)   (12) (13) (14) (15)\n');
fprintf(fid,'*name    dim outp  endpt csys obspt csys outp csys x1beg  x2beg  x3beg  x1end  x2end  x3end  nx1 nx2 nx3\n');
fprintf(fid,'*------- --- ----- ---------- ---------- --------- ------ ------ ------ ------ ------ ------ --- --- ---\n');
fprintf(fid,'OBSgridnorth200 2  esps   CS_AOInorth     global     global    %5.7f  %5.7f  %5.7f  %5.7f  %5.7f  %5.7f  %d  %d  %d\n',OBSgridnorth200);
fprintf(fid,'OBSgridsouth200 2  esps   CS_AOIsouth     global     global    %5.7f  %5.7f  %5.7f  %5.7f  %5.7f  %5.7f  %d  %d  %d\n',OBSgridsouth200); 
fprintf(fid,'\n');
fprintf(fid,'end *(OBSERVATION GRIDS)\n');
fprintf(fid,'*******************************************************************************\n');
fprintf(fid,'*                      Section 4: OBJECTS/ELEMENTS/VERTICES                   *\n');
fprintf(fid,'*                      (o = object, e = element, v = vertex)                  *\n');
fprintf(fid,'*******************************************************************************\n');
%%% Begin Fault Object 1
fprintf(fid,'*(1) (2)            (3)        (4)\n');                        
fprintf(fid,'*o name             outp    eltc csys\n');
fprintf(fid,'*- ---------------- ------- ----------\n');
fprintf(fid,'o  "NorthFault" bt      CrackCS  \n');                            % object name defined (note as defined above elocal (except for BC) are same as global by my choice
fprintf(fid,'\n');
fprintf(fid,'*(1) (2)     (3)       (4)         (5)         (6)\n');
fprintf(fid,'*v name     csys       x1          x2          x3\n');
fprintf(fid,'*- -------- ---------  ------      ------      ------\n');
fprintf(fid,'*Fracture vertices\n');
% "%4.0f" 4 decimal places before the decimal --> integer vertex; for
% "%8.8f" can be increased for greater precision, could also replace with %d
fprintf(fid,'v  %4.0f  global    %8.12f   %8.12f   %8.12f\n', entries1);    
fprintf(fid,'\n');
fprintf(fid,'*(1) (2)   (3)      (4)    (5)       (6)       (7)      (8) (9) (10) (...)\n');
fprintf(fid,'*e #vert BC csys   BC type BC1       BC2       BC3       v1  v2  v3 ...\n');
fprintf(fid,'*- ----- --------- ------- --------- --------- --------- --  --  -- --\n');
fprintf(fid,'*BCs & connectivity \n');
% note that the the BC are specified; e = element, 3 = 3 space dimensions,
% elocla --> BC are in element local: "bbb", b = bergers veger, t = traction, the next 3 numbers are BC magnitudes in dip,strike,normal
fprintf(fid,'e  3     elocal    ttb   %5.5f     %5.5f     %5.5f      %4.0f %4.0f %4.0f\n', fault01);    
fprintf(fid,'\n');
%%% Begin Fault 2: this begins next "fault" --> 11 lines for each "fault object"
fprintf(fid,'*(1) (2)            (3)        (4)\n');                        
fprintf(fid,'*o name             outp    eltc csys\n');                                              
fprintf(fid,'*- ---------------- ------- ----------\n');                                              
fprintf(fid,'o  "NorthFaultShallow" bt      CrackCS  \n');                                                    
fprintf(fid,'\n');  
fprintf(fid,'*(1) (2)     (3)       (4)         (5)         (6)\n');
fprintf(fid,'*v name     csys       x1          x2          x3\n');
fprintf(fid,'*- -------- ---------  ------      ------      ------\n');
fprintf(fid,'*Fracture vertices\n');
fprintf(fid,'v  %4.0f  global    %8.12f   %8.12f   %8.12f\n', entries2);    % "%4.0f" 4 decimal places before the decimal --> integer vertex; for "%8.8f" can be increased for greater precision, could also replace with %d
fprintf(fid,'\n');
fprintf(fid,'*(1) (2)   (3)      (4)    (5)       (6)       (7)      (8) (9) (10) (...)\n');
fprintf(fid,'*e #vert BC csys   BC type BC1       BC2       BC3       v1  v2  v3 ...\n');
fprintf(fid,'*- ----- --------- ------- --------- --------- --------- --  --  -- --\n');
fprintf(fid,'*BCs & connectivity \n');
fprintf(fid,'e  3     elocal    ttb   %5.5f     %5.5f     %5.5f      %4.0f %4.0f %4.0f\n', fault02);
fprintf(fid,'\n');
%%% Begin Fault 3: this begins next "fault" --> 11 lines for each "fault object"
fprintf(fid,'*(1) (2)            (3)        (4)\n');                        
fprintf(fid,'*o name             outp    eltc csys\n');
fprintf(fid,'*- ---------------- ------- ----------\n');
fprintf(fid,'o  "NorthFaultDeep" bt      CrackCS  \n');
fprintf(fid,'\n');  
fprintf(fid,'*(1) (2)     (3)       (4)         (5)         (6)\n');
fprintf(fid,'*v name     csys       x1          x2          x3\n');
fprintf(fid,'*- -------- ---------  ------      ------      ------\n');
fprintf(fid,'*Fracture vertices\n');
fprintf(fid,'v  %4.0f  global    %8.12f   %8.12f   %8.12f\n', entries3);    % "%4.0f" 4 decimal places before the decimal --> integer vertex; for "%8.8f" can be increased for greater precision, could also replace with %d
fprintf(fid,'\n');
fprintf(fid,'*(1) (2)   (3)      (4)    (5)       (6)       (7)      (8) (9) (10) (...)\n');
fprintf(fid,'*e #vert BC csys   BC type BC1       BC2       BC3       v1  v2  v3 ...\n');
fprintf(fid,'*- ----- --------- ------- --------- --------- --------- --  --  -- --\n');
fprintf(fid,'*BCs & connectivity \n');
fprintf(fid,'e  3     elocal    ttb   %5.5f     %5.5f     %5.5f      %4.0f %4.0f %4.0f\n', fault03);
fprintf(fid,'\n');
%%% Begin Fault 4: this begins next "fault" --> 11 lines for each "fault object"
fprintf(fid,'*(1) (2)            (3)        (4)\n');                        
fprintf(fid,'*o name             outp    eltc csys\n');
fprintf(fid,'*- ---------------- ------- ----------\n');
fprintf(fid,'o  "SpudMountanPluton" bt      CrackCS  \n');
fprintf(fid,'\n');  
fprintf(fid,'*(1) (2)     (3)       (4)         (5)         (6)\n');
fprintf(fid,'*v name     csys       x1          x2          x3\n');
fprintf(fid,'*- -------- ---------  ------      ------      ------\n');
fprintf(fid,'*Fracture vertices\n');
fprintf(fid,'v  %4.0f  global    %8.12f   %8.12f   %8.12f\n', entries4);    % "%4.0f" 4 decimal places before the decimal --> integer vertex; for "%8.8f" can be increased for greater precision, could also replace with %d
fprintf(fid,'\n');
fprintf(fid,'*(1) (2)   (3)      (4)    (5)       (6)       (7)      (8) (9) (10) (...)\n');
fprintf(fid,'*e #vert BC csys   BC type BC1       BC2       BC3       v1  v2  v3 ...\n');
fprintf(fid,'*- ----- --------- ------- --------- --------- --------- --  --  -- --\n');
fprintf(fid,'*BCs & connectivity \n');
fprintf(fid,'e  3     elocal    ttb   %5.5f     %5.5f     %5.5f      %4.0f %4.0f %4.0f\n', fault04);
fprintf(fid,'\n');
%%% Begin Fault 5: this begins next "fault" --> 11 lines for each "fault object"
fprintf(fid,'*(1) (2)            (3)        (4)\n');                        
fprintf(fid,'*o name             outp    eltc csys\n');
fprintf(fid,'*- ---------------- ------- ----------\n');
fprintf(fid,'o  "NorthCrossfault" bt      CrackCS  \n');
fprintf(fid,'\n');  
fprintf(fid,'*(1) (2)     (3)       (4)         (5)         (6)\n');
fprintf(fid,'*v name     csys       x1          x2          x3\n');
fprintf(fid,'*- -------- ---------  ------      ------      ------\n');
fprintf(fid,'*Fracture vertices\n');
fprintf(fid,'v  %4.0f  global    %8.12f   %8.12f   %8.12f\n', entries5);    % "%4.0f" 4 decimal places before the decimal --> integer vertex; for "%8.8f" can be increased for greater precision, could also replace with %d
fprintf(fid,'\n');
fprintf(fid,'*(1) (2)   (3)      (4)    (5)       (6)       (7)      (8) (9) (10) (...)\n');
fprintf(fid,'*e #vert BC csys   BC type BC1       BC2       BC3       v1  v2  v3 ...\n');
fprintf(fid,'*- ----- --------- ------- --------- --------- --------- --  --  -- --\n');
fprintf(fid,'*BCs & connectivity \n');
fprintf(fid,'e  3     elocal    ttb   %5.5f     %5.5f     %5.5f      %4.0f %4.0f %4.0f\n', fault05);
fprintf(fid,'\n');
%%% Begin Fault 6: this begins next "fault" --> 11 lines for each "fault object"
fprintf(fid,'*(1) (2)            (3)        (4)\n');                        
fprintf(fid,'*o name             outp    eltc csys\n');
fprintf(fid,'*- ---------------- ------- ----------\n');
fprintf(fid,'o  "SouthFault" bt      CrackCS  \n');
fprintf(fid,'\n');  
fprintf(fid,'*(1) (2)     (3)       (4)         (5)         (6)\n');
fprintf(fid,'*v name     csys       x1          x2          x3\n');
fprintf(fid,'*- -------- ---------  ------      ------      ------\n');
fprintf(fid,'*Fracture vertices\n');
fprintf(fid,'v  %4.0f  global    %8.12f   %8.12f   %8.12f\n', entries6);    % "%4.0f" 4 decimal places before the decimal --> integer vertex; for "%8.8f" can be increased for greater precision, could also replace with %d
fprintf(fid,'\n');
fprintf(fid,'*(1) (2)   (3)      (4)    (5)       (6)       (7)      (8) (9) (10) (...)\n');
fprintf(fid,'*e #vert BC csys   BC type BC1       BC2       BC3       v1  v2  v3 ...\n');
fprintf(fid,'*- ----- --------- ------- --------- --------- --------- --  --  -- --\n');
fprintf(fid,'*BCs & connectivity \n');
fprintf(fid,'e  3     elocal    ttb   %5.5f     %5.5f     %5.5f      %4.0f %4.0f %4.0f\n', fault06);
fprintf(fid,'\n');
%%% Begin Fault 7: this begins next "fault" --> 11 lines for each "fault object"
fprintf(fid,'*(1) (2)            (3)        (4)\n');                        
fprintf(fid,'*o name             outp    eltc csys\n');
fprintf(fid,'*- ---------------- ------- ----------\n');
fprintf(fid,'o  "SouthCrossfault" bt      CrackCS  \n');
fprintf(fid,'\n');  
fprintf(fid,'*(1) (2)     (3)       (4)         (5)         (6)\n');
fprintf(fid,'*v name     csys       x1          x2          x3\n');
fprintf(fid,'*- -------- ---------  ------      ------      ------\n');
fprintf(fid,'*Fracture vertices\n');
fprintf(fid,'v  %4.0f  global    %8.12f   %8.12f   %8.12f\n', entries7);    % "%4.0f" 4 decimal places before the decimal --> integer vertex; for "%8.8f" can be increased for greater precision, could also replace with %d
fprintf(fid,'\n');
fprintf(fid,'*(1) (2)   (3)      (4)    (5)       (6)       (7)      (8) (9) (10) (...)\n');
fprintf(fid,'*e #vert BC csys   BC type BC1       BC2       BC3       v1  v2  v3 ...\n');
fprintf(fid,'*- ----- --------- ------- --------- --------- --------- --  --  -- --\n');
fprintf(fid,'*BCs & connectivity \n');
fprintf(fid,'e  3     elocal    ttb   %5.5f     %5.5f     %5.5f      %4.0f %4.0f %4.0f\n', fault07);
fprintf(fid,'\n');
%%% Begin Magma Chamber:
fprintf(fid,'*(1) (2)            (3)        (4)\n');                        
fprintf(fid,'*o name             outp    eltc csys\n');
fprintf(fid,'*- ---------------- ------- ----------\n');
fprintf(fid,'o  "MagmaChamber" bt      CrackCS  \n');
fprintf(fid,'\n');
fprintf(fid,'*(1) (2)     (3)       (4)         (5)         (6)\n');
fprintf(fid,'*v name     csys       x1          x2          x3\n');
fprintf(fid,'*- -------- ---------  ------      ------      ------\n');
fprintf(fid,'*Fracture vertices\n');
fprintf(fid,'v  %4.0f  global    %8.12f   %8.12f   %8.12f\n', entries8);    % "%4.0f" 4 decimal places before the decimal --> integer vertex; for "%8.8f" can be increased for greater precision, could also replace with %d
fprintf(fid,'\n');
fprintf(fid,'*(1) (2)   (3)      (4)    (5)       (6)       (7)      (8) (9) (10) (...)\n');
fprintf(fid,'*e #vert BC csys   BC type BC1       BC2       BC3       v1  v2  v3 ...\n');
fprintf(fid,'*- ----- --------- ------- --------- --------- --------- --  --  -- --\n');
fprintf(fid,'*BCs & connectivity \n');
fprintf(fid,'e  3     elocal    ttt   %5.5f     %5.5f     %5.5f      %4.0f %4.0f %4.0f\n', fault08);
fprintf(fid,'\n');
fprintf(fid,'\n');
fprintf(fid,'end *(OBJECTS/ELEMENTS/VERTICES)\n');
fclose(fid);
